// Gary Yngve
// 10/1/2005
     // Stronger, more defensive technique than enumerations -- see J. Bloch

     // A MineCell can have six and only six values:
    // OOB -- out of bounds
    // MARKEDMINE -- marked, and a mine really is there
    // MARKEDEMPTY -- marked, but no mine is there
    // CLEAREDEMPTY -- explored safely (no mine)
    // UNEXPLOREDMINE -- unexplored, mine is there
    // UNEXPLOREDEMPTY -- unexplored, safe (no mine)


import java.util.*;

public class MineCell {
    // each instance is identified by a name and a shortname
    private final String name;
    private final String shortName;

    // a legend records the mappings of shortnames to names
    private static List legend = new ArrayList();

    // private constructor so no one else can create an instance of MineCell
    private MineCell(String name, String shortName) {
        this.name = name;
        this.shortName = shortName;
        legend.add(this.shortName + " = " + this.name);
    }

    public String toString() {
        return name;
    }

    public String toShortString() {
        return shortName;
    }

    public static String legendToString() {
        return legend.toString();
    }

    // these are the only instances of MineCell allowed, created when the
    //program starts, so you can find a match using == (reference equality)
    public static final MineCell OOB =
        new MineCell("(OOB)", "O");
    public static final MineCell MARKEDMINE =
        new MineCell("(Marked mine correctly)", "M");
    public static final MineCell MARKEDEMPTY =
        new MineCell("(Marked mine wrongly)", "X");
    public static final MineCell CLEAREDEMPTY =
        new MineCell("(Cleared empty)", "E");
    public static final MineCell UNEXPLOREDMINE =
        new MineCell("(Unexplored mine)", "m");
    public static final MineCell UNEXPLOREDEMPTY =
        new MineCell("(Unexplored empty)", "e");
}